@@ -10,7 +10,7 @@ use Carp qw(croak carp);
 #######################
 # VERSION
 #######################
-our $VERSION = '0.06';
+our $VERSION = '0.061';
 
 #######################
 # LOAD CPAN MODULES
@@ -142,17 +142,17 @@ TMDB - Perl wrapper for The MovieDB API
 
 =head1 DESCRIPTION
 
-L<The MovieDB|http://www.themoviedb.org/> is a free and open movie database.
-This module provides a Perl wrapper to L<The MovieDB
-API|http://help.themoviedb.org/kb/api/about-3>. In order to use this module,
-you must first get an API key by L<signing
+L<The MovieDB|http://www.themoviedb.org/> is a free and open movie
+database. This module provides a Perl wrapper to L<The MovieDB
+API|http://help.themoviedb.org/kb/api/about-3>. In order to use this
+module, you must first get an API key by L<signing
 up|http://www.themoviedb.org/account/signup>.
 
-B<NOTE:> TMDB-v0.04 and higher uses TheMoviDB API version C</3>. This brings
-some significant differences both to the API and the interface this module
-provides, along with updated dependencies for this distribution. If you like to
-continue to use v2.1 API, you can continue to use
-L<TMDB-0.03x|https://metacpan.org/release/MITHUN/TMDB-0.03/>.
+B<NOTE:> TMDB-v0.04 and higher uses TheMoviDB API version C</3>. This
+brings some significant differences both to the API and the interface
+this module provides, along with updated dependencies for this
+distribution. If you like to continue to use v2.1 API, you can continue
+to use L<TMDB-0.03x|https://metacpan.org/release/MITHUN/TMDB-0.03/>.
 
 =head1 INITIALIZATION
 
@@ -174,21 +174,22 @@ This is your API key
 
 =item lang
 
-This must be a valid ISO 639-1 (Alpha-2) language code. Note that with C</3>,
-the API no longer falls back to an English default.
+This must be a valid ISO 639-1 (Alpha-2) language code. Note that with
+C</3>, the API no longer falls back to an English default.
 
 L<List of ISO 639-1
 codes|http://en.wikipedia.org/wiki/List_of_ISO_639-1_codes>.
 
 =item client
 
-You can provide your own L<HTTP::Client> object, otherwise a default one is
-used.
+You can provide your own L<HTTP::Client> object, otherwise a default
+one is used.
 
 =item json
 
-You can provide your own L<JSON> implementation that can C<decode> JSON. This
-will fall back to using L<JSON::Any>. However, L<JSON::XS> is recommended.
+You can provide your own L<JSON> implementation that can C<decode>
+JSON. This will fall back to using L<JSON::Any>. However, L<JSON::XS>
+is recommended.
 
 =back
 
@@ -380,18 +381,21 @@ This module not (yet!) support POST-ing data to TheMovieDB
 
 All data returned is UTF-8 encoded
 
-Please report any bugs or feature requests to C<bug-tmdb@rt.cpan.org>, or
-through the web interface at
+Please report any bugs or feature requests to C<bug-tmdb@rt.cpan.org>,
+or through the web interface at
 L<http://rt.cpan.org/Public/Dist/Display.html?Name=TMDB>
 
 =head1 SEE ALSO
 
+=over
+
 =item L<The MovieDB API|http://help.themoviedb.org/kb/api/about-3>
 
 =item L<API Support|http://help.themoviedb.org/discussions/problems>
 
 =item L<WWW::TMDB::API>
 
+=back
 
 =head1 AUTHOR
 
@@ -401,7 +405,7 @@ Mithun Ayachit C<mithun@cpan.org>
 
 Copyright (c) 2012, Mithun Ayachit. All rights reserved.
 
-This module is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself. See L<perlartistic>.
+This module is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself. See L<perlartistic>.
 
 =cut
