@@ -34,14 +34,12 @@ sub new {
                 type => OBJECT,
                 isa  => 'TMDB::Session',
             },
-            id => {
-                type => SCALAR,
-            },
+            id => { type => SCALAR, },
         },
     );
 
     my $self = $class->SUPER::new(%opts);
-  return $self;
+    return $self;
 } ## end sub new
 
 ## ====================
@@ -49,7 +47,7 @@ sub new {
 ## ====================
 sub info {
     my $self = shift;
-  return $self->session->talk(
+    return $self->session->talk(
         {
             method => 'collection/' . $self->id(),
             params => {
@@ -74,7 +72,7 @@ sub version {
     ) or return;
     my $version = $response->{etag} || q();
     $version =~ s{"}{}gx;
-  return $version;
+    return $version;
 } ## end sub version
 
 ## ====================
@@ -91,7 +89,6 @@ sub ids { return shift->_parse_parts('id'); }
 # PRIVATE METHODS
 #######################
 
-
 sub _parse_parts {
     my $self  = shift;
     my $key   = shift;
@@ -99,11 +96,11 @@ sub _parse_parts {
     my $parts = $info ? $info->{parts} : [];
     my @stuff;
     foreach my $part (@$parts) {
-      next unless $part->{$key};
+        next unless $part->{$key};
         push @stuff, $part->{$key};
-    } ## end foreach my $part (@$parts)
-  return @stuff if wantarray;
-  return \@stuff;
+    }
+    return @stuff if wantarray;
+    return \@stuff;
 } ## end sub _parse_parts
 
 #######################
